Contributors Guide
==================

These pages target people who are interested in contributing directly to the Jupyter Enterprise Gateway Project.

.. admonition:: Use cases

    - *As a contributor, I want to learn more about kernel management within the Jupyter ecosystem.*
    - *As a contributor, I want to make Enterprise Gateway a more stable service for my organization and the community as a whole.*
    - *As a contributor, I'm interested in adding the ability for Enterprise Gateway to be highly available and fault tolerant.*

.. note::
   As a *contributor*, we encourage you to be familiar with all of the guides (Users, Developers, Operators) to best support Enterprise Gateway.  This guide provides an overview of Enterprise Gateway along with instructions on how to get set up.


.. toctree::
   :maxdepth: 1
   :name: contributors

   contrib
   system-architecture
   docker
   devinstall
   sequence-diagrams
   API Docs <../api/modules>
   debug
